/*--------------------------------------------------------------------*/
/*     Copyright (C) 2004-2016  Serge Iovleff

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as
    published by the Free Software Foundation; either version 2 of the
    License, or (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this program; if not, write to the
    Free Software Foundation, Inc.,
    59 Temple Place,
    Suite 330,
    Boston, MA 02111-1307
    USA

    Contact : S..._Dot_I..._At_stkpp_Dot_org (see copyright for ...)
*/

/*
 * Project:  stkpp::Clustering
 * created on: 16 oct. 2012
 * Author:   iovleff, S..._Dot_I..._At_stkpp_Dot_org (see copyright for ...)
 * Originally created by Parmeet Bhatia <b..._DOT_p..._AT_gmail_Dot_com>
 **/

/** @file STK_IMixtureModelBase.cpp
 *  @brief In this file we implement the interface base class IMixtureModelBase
 **/

#include <Clustering/include/STK_IMixtureModelBase.h>

namespace STK
{


/* default constructor */
IMixtureModelBase::IMixtureModelBase( int nbCluster)
                                    : nbCluster_(nbCluster)
                                    , nbSample_(0)
{}
/* copy constructor. If the pointer on the mixture parameters are not zero
 *  then they are cloned.
 *  @note if the model have not created the parameters, then the pointer are
 *  initialized to 0.
 *  @param model the model to clone
 **/
IMixtureModelBase::IMixtureModelBase( IMixtureModelBase const& model)
                                    : nbCluster_(model.nbCluster_)
                                    , nbSample_(model.nbSample_)
{}

/* destructor */
IMixtureModelBase::~IMixtureModelBase() {}

} // namespace STK

